@@ -123,6 +123,12 @@ void wake_expired_tasks(void);
  */
 int next_timer_expiry(void);
 
+/* Pings the scheduler to verify that tasks continue running for thread <thr>.
+ * Returns 1 if the scheduler made progress since last call, 0 if it looks
+ * stuck. It marks it as stuck for next visit.
+ */
+int is_sched_alive(int thr);
+
 /*
  * Delete every tasks before running the master polling loop
  */
@@ -380,7 +386,7 @@ static inline void task_set_thread(struct task *t, int thr)
  * flag is added).
  */
 #define tasklet_wakeup_on(tl, thr, ...)					\
-	_tasklet_wakeup_on(tl, thr, DEFZERO(__VA_ARGS__), MK_CALLER(WAKEUP_TYPE_TASKLET_WAKEUP, 0, 0))
+	_tasklet_wakeup_on(tl, thr, DEFVAL(TASK_WOKEN_OTHER, ##__VA_ARGS__), MK_CALLER(WAKEUP_TYPE_TASKLET_WAKEUP, 0, 0))
 
 static inline void _tasklet_wakeup_on(struct tasklet *tl, int thr, uint f, const struct ha_caller *caller)
 {
@@ -388,9 +394,9 @@ static inline void _tasklet_wakeup_on(struct tasklet *tl, int thr, uint f, const
 
 	do {
 		/* do nothing if someone else already added it */
-		if (state & TASK_IN_LIST)
+		if (state & TASK_QUEUED)
 			return;
-	} while (!_HA_ATOMIC_CAS(&tl->state, &state, state | TASK_IN_LIST));
+	} while (!_HA_ATOMIC_CAS(&tl->state, &state, state | TASK_QUEUED));
 
 	/* at this point we're the first ones to add this task to the list */
 	if (likely(caller)) {
@@ -417,7 +423,7 @@ static inline void _tasklet_wakeup_on(struct tasklet *tl, int thr, uint f, const
  * flag is added).
  */
 #define tasklet_wakeup(tl, ...)						\
-	_tasklet_wakeup_on(tl, (tl)->tid, DEFZERO(__VA_ARGS__), MK_CALLER(WAKEUP_TYPE_TASKLET_WAKEUP, 0, 0))
+	_tasklet_wakeup_on(tl, (tl)->tid, DEFVAL(TASK_WOKEN_OTHER, ##__VA_ARGS__), MK_CALLER(WAKEUP_TYPE_TASKLET_WAKEUP, 0, 0))
 
 /* instantly wakes up task <t> on its owner thread even if it's not the current
  * one, bypassing the run queue. The purpose is to be able to avoid contention
@@ -479,11 +485,14 @@ static inline void _task_instant_wakeup(struct task *t, unsigned int f, const st
  *
  * The macro accepts an optional 3rd argument that is passed as a set of flags
  * to be set on the tasklet, among TASK_WOKEN_*, TASK_F_UEVT* etc to indicate a
- * wakeup cause to the tasklet. When not set, the arg defaults to zero (i.e. no
- * flag is added).
+ * wakeup cause to the tasklet. When not set, the arg defaults to
+ * TASK_WOKEN_OTHER, so that tasklets can differentiate a unique explicit wakeup
+ * cause from a wakeup cause combined with other implicit ones. I.e. that may be
+ * used by muxes to decide whether or not to perform a short path for certain
+ * operations, or a complete one that also covers regular I/O.
  */
 #define tasklet_wakeup_after(head, tl, ...)					\
-	_tasklet_wakeup_after(head, tl, DEFZERO(__VA_ARGS__), MK_CALLER(WAKEUP_TYPE_TASKLET_WAKEUP_AFTER, 0, 0))
+	_tasklet_wakeup_after(head, tl, DEFVAL(TASK_WOKEN_OTHER, ##__VA_ARGS__), MK_CALLER(WAKEUP_TYPE_TASKLET_WAKEUP_AFTER, 0, 0))
 
 static inline struct list *_tasklet_wakeup_after(struct list *head, struct tasklet *tl,
                                                  uint f, const struct ha_caller *caller)
@@ -492,9 +501,9 @@ static inline struct list *_tasklet_wakeup_after(struct list *head, struct taskl
 
 	do {
 		/* do nothing if someone else already added it */
-		if (state & TASK_IN_LIST)
+		if (state & TASK_QUEUED)
 			return head;
-	} while (!_HA_ATOMIC_CAS(&tl->state, &state, state | TASK_IN_LIST));
+	} while (!_HA_ATOMIC_CAS(&tl->state, &state, state | TASK_QUEUED));
 
 	/* at this point we're the first one to add this task to the list */
 	if (likely(caller)) {
@@ -525,21 +534,6 @@ static inline struct list *_tasklet_wakeup_after(struct list *head, struct taskl
 #define DEBUG_TASK_PRINT_CALLER(t) do { } while (0)
 #endif
 
-
-/* Try to remove a tasklet from the list. This call is inherently racy and may
- * only be performed on the thread that was supposed to dequeue this tasklet.
- * This way it is safe to call MT_LIST_DELETE without first removing the
- * TASK_IN_LIST bit, which must absolutely be removed afterwards in case
- * another thread would want to wake this tasklet up in parallel.
- */
-static inline void tasklet_remove_from_tasklet_list(struct tasklet *t)
-{
-	if (MT_LIST_DELETE(list_to_mt_list(&t->list))) {
-		_HA_ATOMIC_AND(&t->state, ~TASK_IN_LIST);
-		_HA_ATOMIC_DEC(&ha_thread_ctx[t->tid >= 0 ? t->tid : tid].rq_total);
-	}
-}
-
 /*
  * Initialize a new task. The bare minimum is performed (queue pointers and
  * state).  The task is returned. This function should not be used outside of
@@ -790,22 +784,12 @@ static inline struct notification *_notification_new(struct list *purge, struct
  * events like TCP I/O or sleep functions. This function allocate
  * memory for the signal.
  */
-static inline struct notification *notification_new(struct list *purge, struct list *event, struct task *wakeup)
+static inline struct notification *notification_new(struct list *purge, struct mt_list *event, struct task *wakeup)
 {
 	struct notification *com = _notification_new(purge, wakeup);
 	if (!com)
 		return NULL;
-	LIST_APPEND(event, &com->wake_me);
-	return com;
-}
-
-/* thread safe variant */
-static inline struct notification *notification_new_mt(struct list *purge, struct mt_list *event, struct task *wakeup)
-{
-	struct notification *com = _notification_new(purge, wakeup);
-	if (!com)
-		return NULL;
-	MT_LIST_APPEND(event, &com->wake_me_mt);
+	MT_LIST_APPEND(event, &com->wake_me);
 	return com;
 }
 
@@ -869,29 +853,15 @@ static inline void _notification_wake(struct notification *com)
 }
 /* This function sends signals. It wakes all the tasks attached
  * to a list head, and remove the signal, and free the used
- * memory. The wake list is not locked because it is owned by
- * only one process. before browsing this list, the caller must
- * ensure to be the only one browser.
+ * memory.
  */
-static inline void notification_wake(struct list *wake)
-{
-	struct notification *com, *back;
-
-	/* Wake task and delete all pending communication signals. */
-	list_for_each_entry_safe(com, back, wake, wake_me) {
-		LIST_DELETE(&com->wake_me);
-		_notification_wake(com);
-	}
-}
-
-/* thread safe variant */
-static inline void notification_wake_mt(struct mt_list *wake)
+static inline void notification_wake(struct mt_list *wake)
 {
 	struct notification *com;
 	struct mt_list back;
 
 	/* Wake task and delete all pending communication signals. */
-	MT_LIST_FOR_EACH_ENTRY_UNLOCKED(com, wake, wake_me_mt, back) {
+	MT_LIST_FOR_EACH_ENTRY_UNLOCKED(com, wake, wake_me, back) {
 		_notification_wake(com);
 		com = NULL;
 	}
@@ -899,9 +869,9 @@ static inline void notification_wake_mt(struct mt_list *wake)
 
 /* This function returns true is some notification are pending
  */
-static inline int notification_registered(struct list *wake)
+static inline int notification_registered(struct mt_list *wake)
 {
-	return !LIST_ISEMPTY(wake);
+	return !MT_LIST_ISEMPTY(wake);
 }
 
 #endif /* _HAPROXY_TASK_H */
