@@ -30,7 +30,7 @@
 #define TRACE_SOURCE &trace_strm
 
 /* Pool used to allocate filters */
-DECLARE_STATIC_POOL(pool_head_filter, "filter", sizeof(struct filter));
+DECLARE_STATIC_TYPED_POOL(pool_head_filter, "filter", struct filter);
 
 static int handle_analyzer_result(struct stream *s, struct channel *chn, unsigned int an_bit, int ret);
 
@@ -684,7 +684,6 @@ int
 flt_http_payload(struct stream *s, struct http_msg *msg, unsigned int len)
 {
 	struct filter *filter;
-	struct htx *htx;
 	unsigned long long *strm_off = &FLT_STRM_OFF(s, msg->chn);
 	unsigned int out = co_data(msg->chn);
 	int ret, data;
@@ -734,10 +733,7 @@ flt_http_payload(struct stream *s, struct http_msg *msg, unsigned int len)
 	ret = data;
 	*strm_off += ret;
  end:
-	htx = htxbuf(&msg->chn->buf);
-	htx->flags |= HTX_FL_ALTERED_PAYLOAD;
-	if (msg->flags & HTTP_MSGF_XFER_LEN)
-		htx->extra = 0;
+	chn_prod(msg->chn)->sedesc->kip = 0;
 	DBG_TRACE_LEAVE(STRM_EV_STRM_ANA|STRM_EV_HTTP_ANA|STRM_EV_FLT_ANA, s);
 	return ret;
 }
@@ -1019,6 +1015,7 @@ flt_tcp_payload(struct stream *s, struct channel *chn, unsigned int len)
 		*strm_off += ret;
 	}
  end:
+	chn_prod(chn)->sedesc->kip = 0;
 	DBG_TRACE_LEAVE(STRM_EV_TCP_ANA|STRM_EV_FLT_ANA, s);
 	return ret;
 }
