@@ -105,9 +105,9 @@ int compute_ideal_maxpipes()
 
 /* considers global.maxsocks, global.maxpipes, async engines, SSL frontends and
  * rlimits and computes an ideal maxconn. It's meant to be called only when
- * maxsock contains the sum of listening FDs, before it is updated based on
- * maxconn and pipes. If there are not enough FDs left, DEFAULT_MAXCONN (by
- * default 100) is returned as it is expected that it will even run on tight
+ * global.est_fd_usage contains the sum of listening FDs, before it is updated
+ * based on maxconn and pipes. If there are not enough FDs left, DEFAULT_MAXCONN
+ * (by default 100) is returned as it is expected that it will even run on tight
  * environments, and will maintain compatibility with previous packages that
  * used to rely on this value as the default one. The system will emit a
  * warning indicating how many FDs are missing anyway if needed.
@@ -162,13 +162,7 @@ static int compute_ideal_maxconn()
 	}
 
 	/* subtract listeners and checks */
-	remain -= global.maxsock;
-
-	/* one epoll_fd/kqueue_fd per thread */
-	remain -= global.nbthread;
-
-	/* one wake-up pipe (2 fd) per thread */
-	remain -= 2 * global.nbthread;
+	remain -= global.est_fd_usage;
 
 	/* Fixed pipes values : we only subtract them if they're not larger
 	 * than the remaining FDs because pipes are optional.
@@ -291,8 +285,7 @@ void set_global_maxconn(void)
 	if (!global.rlimit_memmax) {
 		if (global.maxconn == 0) {
 			global.maxconn = ideal_maxconn;
-			if (global.mode & (MODE_VERBOSE|MODE_DEBUG))
-				fprintf(stderr, "Note: setting global.maxconn to %d.\n", global.maxconn);
+			ha_notice("Automatically setting global.maxconn to %d.\n", global.maxconn);
 		}
 	}
 #ifdef USE_OPENSSL
@@ -338,10 +331,8 @@ void set_global_maxconn(void)
 			if (check_if_maxsock_permitted(compute_ideal_maxsock(global.maxconn)))
 				break;
 		} while (retried++ < 2);
-
-		if (global.mode & (MODE_VERBOSE|MODE_DEBUG))
-			fprintf(stderr, "Note: setting global.maxconn to %d and global.maxsslconn to %d.\n",
-			        global.maxconn, global.maxsslconn);
+		ha_notice("Automatically setting global.maxconn to %d and global.maxsslconn to %d.\n",
+		          global.maxconn, global.maxsslconn);
 	}
 	else if (!global.maxsslconn &&
 		 (global.ssl_used_frontend || global.ssl_used_backend)) {
@@ -460,8 +451,19 @@ void apply_nofile_limit(void)
 				limit.rlim_cur = global.fd_hard_limit;
 
 			if (global.tune.options & GTUNE_STRICT_LIMITS) {
-				ha_alert("[%s.main()] Cannot raise FD limit to %d, limit is %d.\n",
-					 progname, global.rlimit_nofile, (int)limit.rlim_cur);
+				/* suggest roughly half of the limit minus used FDs for listeners, checks
+				 * etc. This will give roughly round numbers for 64k and above while
+				 * reserving enough listeners for small values such as 1024.
+				 */
+				ha_alert("[%s.main()] Cannot raise FD limit to %d, current "
+					 "limit is %d and hard limit is %d. You may prefer to let HAProxy "
+					 "adjust the limit by itself; for this, please just drop any 'maxconn' and "
+					 "'ulimit-n' from the global section, and possibly add 'fd-hard-limit' lower "
+					 "than this hard limit. You may also force a new 'maxconn' value that is a bit "
+					 "lower than half of the hard limit minus listeners and checks. This results in "
+					 "roughly %u here.\n",
+					 progname, global.rlimit_nofile, (int)limit.rlim_cur, (int)limit.rlim_max,
+					 round_2dig((uint)MAX(limit.rlim_max - global.est_fd_usage, 3) * 49ULL / 100));
 				exit(1);
 			}
 			else {
@@ -475,6 +477,16 @@ void apply_nofile_limit(void)
 
 				ha_warning("[%s.main()] Cannot raise FD limit to %d, limit is %d.\n",
 					   progname, global.rlimit_nofile, (int)limit.rlim_cur);
+
+				ha_warning("[%s.main()] Cannot raise FD limit to %d, current "
+					   "limit is %d and hard limit is %d. You may prefer to let HAProxy "
+					   "adjust the limit by itself; for this, please just drop any 'maxconn' and "
+					   "'ulimit-n' from the global section, and possibly add 'fd-hard-limit' lower "
+					   "than this hard limit. You may also force a new 'maxconn' value that is a bit "
+					   "lower than half of the hard limit minus listeners and checks. This results in "
+					   "roughly %u here.\n",
+					   progname, global.rlimit_nofile, (int)limit.rlim_cur, (int)limit.rlim_max,
+					   round_2dig((uint)MAX(limit.rlim_max - global.est_fd_usage, 3) * 49ULL / 100));
 				global.rlimit_nofile = limit.rlim_cur;
 			}
 		}
