@@ -509,6 +509,14 @@ void mworker_catch_sigterm(struct sig_handler *sh)
 	mworker_kill(sig);
 }
 
+/* handle operations that can't be done in the signal handler */
+static struct task *mworker_task_child_failure(struct task *task, void *context, unsigned int state)
+{
+	mworker_unblock_signals();
+	task_destroy(task);
+	return NULL;
+}
+
 /*
  * Performs some routines for the worker process, which has failed the reload,
  * updates the global load_status.
@@ -516,6 +524,7 @@ void mworker_catch_sigterm(struct sig_handler *sh)
 static void mworker_on_new_child_failure(int exitpid, int status)
 {
 	struct mworker_proc *child;
+	struct task *t;
 
 	/* increment the number of failed reloads */
 	list_for_each_entry(child, &proc_list, list) {
@@ -532,6 +541,15 @@ static void mworker_on_new_child_failure(int exitpid, int status)
 	 * the READY=1 signal still need to be sent */
 	if (global.tune.options & GTUNE_USE_SYSTEMD)
 		sd_notify(0, "READY=1\nSTATUS=Reload failed!\n");
+
+	/* call a task to unblock the signals from outside the sig handler */
+	if ((t = task_new_here()) == NULL) {
+		ha_warning("Can't restore HAProxy signals!\n");
+		return;
+	}
+
+	t->process = mworker_task_child_failure;
+	task_wakeup(t, TASK_WOKEN_MSG);
 }
 
 /*
@@ -808,7 +826,7 @@ void mworker_cleanup_proc()
 
 struct cli_showproc_ctx {
 	int debug;
-	int next_uptime; /* uptime must be greater than this value */
+	int next_reload; /* reload number to resume from, 0 = from the beginning  */
 };
 
 /*  Displays workers and processes  */
@@ -826,7 +844,7 @@ static int cli_io_handler_show_proc(struct appctx *appctx)
 
 	chunk_reset(&trash);
 
-	if (ctx->next_uptime == 0) {
+	if (ctx->next_reload == 0) {
 		memprintf(&reloadtxt, "%d [failed: %d]", proc_self->reloads, proc_self->failedreloads);
 		chunk_printf(&trash, "#%-14s %-15s %-15s %-15s %-15s", "<PID>", "<type>", "<reloads>", "<uptime>", "<version>");
 		if (ctx->debug)
@@ -844,12 +862,12 @@ static int cli_io_handler_show_proc(struct appctx *appctx)
 	ha_free(&uptime);
 
 	/* displays current processes */
-	if (ctx->next_uptime == 0)
+	if (ctx->next_reload == 0)
 		chunk_appendf(&trash, "# workers\n");
 	list_for_each_entry(child, &proc_list, list) {
 
 		/* don't display current worker if we only need the next ones */
-		if (ctx->next_uptime != 0)
+		if (ctx->next_reload != 0)
 			continue;
 
 		up = date.tv_sec - child->timestamp;
@@ -875,15 +893,16 @@ static int cli_io_handler_show_proc(struct appctx *appctx)
 		return 0;
 
 	/* displays old processes */
-	if (old || ctx->next_uptime) { /* there's more */
-		if (ctx->next_uptime == 0)
+	if (old || ctx->next_reload) { /* there's more */
+		if (ctx->next_reload == 0)
 			chunk_appendf(&trash, "# old workers\n");
 		list_for_each_entry(child, &proc_list, list) {
 			up = date.tv_sec - child->timestamp;
 			if (up <= 0) /* must never be negative because of clock drift */
 				up = 0;
 
-			if (child->timestamp < ctx->next_uptime)
+			/* If we're resuming, skip entries that were already printed (reload >= ctx->next_reload) */
+			if (ctx->next_reload && child->reloads >= ctx->next_reload)
 				continue;
 
 			if (!(child->options & PROC_O_TYPE_WORKER))
@@ -896,17 +915,21 @@ static int cli_io_handler_show_proc(struct appctx *appctx)
 					chunk_appendf(&trash, "\t\t %-15d %-15d", child->ipc_fd[0], child->ipc_fd[1]);
 				chunk_appendf(&trash, "\n");
 				ha_free(&uptime);
+
+				/* Try to flush so we can resume after this reload on next page if the buffer is full. */
+				if (applet_putchk(appctx, &trash) == -1) {
+					/* resume at this reload (exclude it on next pass) */
+					ctx->next_reload = child->reloads; /* resume after entries >= this reload */
+					return 0;
+				}
+				chunk_reset(&trash);
 			}
 
-			/* start from there if there's not enough place */
-			ctx->next_uptime = child->timestamp;
-
-			if (applet_putchk(appctx, &trash) == -1)
-				return 0;
 		}
 	}
 
-	/* dump complete */
+	/* dump complete: reset resume cursor so next 'show proc' starts from the top */
+	ctx->next_reload = 0;
 	return 1;
 }
 /* reload the master process */
