@@ -1124,6 +1124,7 @@ struct task *qc_process_timer(struct task *task, void *ctx, unsigned int state)
 struct quic_conn *qc_new_conn(void *target,
                               const struct quic_rx_packet *initial_pkt,
                               const struct quic_cid *token_odcid,
+                              struct connection *conn,
                               struct quic_connection_id *conn_id,
                               struct sockaddr_storage *local_addr,
                               struct sockaddr_storage *peer_addr)
@@ -1132,7 +1133,8 @@ struct quic_conn *qc_new_conn(void *target,
 	struct listener *l = objt_listener(target);
 	struct server *srv = objt_server(target);
 	struct proxy *prx = l ? l->bind_conf->frontend : __objt_server(target)->proxy;
-	struct quic_cc_algo *cc_algo = NULL;
+	const struct quic_cc_algo *cc_algo = NULL;
+	size_t max_cwnd;
 	unsigned int next_actconn = 0, next_sslconn = 0, next_handshake = 0;
 
 	TRACE_ENTER(QUIC_EV_CONN_INIT);
@@ -1197,7 +1199,7 @@ struct quic_conn *qc_new_conn(void *target,
 	qc->idle_timer_task = NULL;
 
 	qc->xprt_ctx = NULL;
-	qc->conn = NULL;
+	qc->conn = conn;
 	qc->qcc = NULL;
 	qc->app_ops = NULL;
 	qc->path = NULL;
@@ -1234,6 +1236,7 @@ struct quic_conn *qc_new_conn(void *target,
 	/* QUIC Server (or listener). */
 	if (l) {
 		cc_algo = l->bind_conf->quic_cc_algo;
+		max_cwnd = l->bind_conf->max_cwnd;
 
 		qc->flags = 0;
 
@@ -1252,6 +1255,9 @@ struct quic_conn *qc_new_conn(void *target,
 	}
 	/* QUIC Client (outgoing connection to servers) */
 	else {
+		cc_algo = srv->quic_cc_algo;
+		max_cwnd = srv->quic_max_cwnd;
+
 		qc->flags = QUIC_FL_CONN_IS_BACK|QUIC_FL_CONN_PEER_VALIDATED_ADDR;
 		/* Duplicate GSO status on server to connection */
 		if (HA_ATOMIC_LOAD(&srv->flags) & SRV_F_UDP_GSO_NOTSUPP)
@@ -1347,8 +1353,8 @@ struct quic_conn *qc_new_conn(void *target,
 	/* Only one path at this time (multipath not supported) */
 	qc->path = &qc->paths[0];
 	quic_cc_path_init(qc->path, peer_addr->ss_family == AF_INET,
-	                  l ? l->bind_conf->max_cwnd : quic_tune.be.cc_max_win_size,
-	                  cc_algo ? cc_algo : default_quic_cc_algo, qc);
+	                  max_cwnd, cc_algo ? cc_algo : default_quic_cc_algo,
+	                  qc);
 
 	if (local_addr)
 		memcpy(&qc->local_addr, local_addr, sizeof(qc->local_addr));
@@ -1716,9 +1722,13 @@ void qc_idle_timer_do_rearm(struct quic_conn *qc, int arm_ack)
 {
 	unsigned int expire;
 
+	TRACE_ENTER(QUIC_EV_CONN_IDLE_TIMER, qc);
+
 	/* It is possible the idle timer task has been already released. */
-	if (!qc->idle_timer_task)
-		return;
+	if (!qc->idle_timer_task) {
+		TRACE_PROTO("idle timer already released", QUIC_EV_CONN_IDLE_TIMER, qc);
+		goto leave;
+	}
 
 	if (qc->flags & (QUIC_FL_CONN_CLOSING|QUIC_FL_CONN_DRAINING)) {
 		/* RFC 9000 10.2. Immediate Close
@@ -1747,6 +1757,8 @@ void qc_idle_timer_do_rearm(struct quic_conn *qc, int arm_ack)
 		expire = QUIC_MAX(3 * quic_pto(qc), qc->max_idle_timeout);
 	}
 
+	TRACE_PRINTF(TRACE_LEVEL_PROTO, QUIC_EV_CONN_IDLE_TIMER, qc, 0, 0, 0,
+	             "quic_pto=%u expire=%u", quic_pto(qc), expire);
 	qc->idle_expire = tick_add(now_ms, MS_TO_TICKS(expire));
 	/* Note that the ACK timer is not armed during the handshake. So,
 	 * the handshake expiration date is taken into an account only
@@ -1768,6 +1780,9 @@ void qc_idle_timer_do_rearm(struct quic_conn *qc, int arm_ack)
 		task_queue(qc->idle_timer_task);
 		TRACE_PROTO("idle timer armed", QUIC_EV_CONN_IDLE_TIMER, qc);
 	}
+
+ leave:
+	TRACE_LEAVE(QUIC_EV_CONN_IDLE_TIMER, qc);
 }
 
 /* Rearm the idle timer or ack timer for <qc> QUIC connection depending on <read>
