@@ -13,7 +13,7 @@
 #include <errno.h>
 
 #include <import/eb64tree.h>
-#include <import/ebistree.h>
+#include <import/cebis_tree.h>
 
 #include <haproxy/api.h>
 #include <haproxy/backend.h>
@@ -321,7 +321,9 @@ static void srv_state_srv_update(struct server *srv, int version, char **params)
 			srv_adm_set_drain(srv);
 	}
 
-	srv->counters.last_change = ns_to_sec(now_ns) - srv_last_time_change;
+	srv->last_change = ns_to_sec(now_ns) - srv_last_time_change;
+	if (srv->counters.shared.tg[0])
+		HA_ATOMIC_STORE(&srv->counters.shared.tg[0]->last_state_change, srv->last_change);
 	srv->check.status = srv_check_status;
 	srv->check.result = srv_check_result;
 
@@ -392,8 +394,6 @@ static void srv_state_srv_update(struct server *srv, int version, char **params)
 	 */
 	else if (fqdn && !srv->hostname && srvrecord) {
 		int res;
-		int i;
-		char *tmp;
 
 		/* we can't apply previous state if SRV record has changed */
 		if (!srv->srvrq) {
@@ -416,16 +416,9 @@ static void srv_state_srv_update(struct server *srv, int version, char **params)
 		 * since this server has an hostname
 		 */
 		LIST_DEL_INIT(&srv->srv_rec_item);
-		srv->host_dn.key = tmp = strdup(srv->hostname_dn);
-
-		/* convert the key in lowercase because tree
-		 * lookup is case sensitive but we don't care
-		 */
-		for (i = 0; tmp[i]; i++)
-			tmp[i] = tolower((unsigned char)tmp[i]);
 
 		/* insert in tree and set the srvrq expiration date */
-		ebis_insert(&srv->srvrq->named_servers, &srv->host_dn);
+		cebis_item_insert(&srv->srvrq->named_servers, host_dn, hostname_dn, srv);
 		task_schedule(srv->srvrq_check, tick_add(now_ms, srv->srvrq->resolvers->timeout.resolve +
 							 srv->srvrq->resolvers->resolve_retries *
 							 srv->srvrq->resolvers->timeout.retry));
